defmodule Nulla.Models.Follow do
  use Ecto.Schema
  import Ecto.Changeset
  alias Nulla.Snowflake
  alias Nulla.Models.Follow

  @primary_key {:id, :integer, autogenerate: false}
  schema "follows" do
    belongs_to :user, Nulla.Models.User
    belongs_to :target, Nulla.Models.User

    timestamps()
  end

  @doc false
  def changeset(follow, attrs) do
    follow
    |> cast(attrs, [:user_id, :target_id])
    |> validate_required([:user_id, :target_id])
    |> unique_constraint([:user_id, :target_id])
  end

  def create_follow(attrs) do
    id = Snowflake.next_id()

    %Follow{}
    |> Follow.changeset(attrs)
    |> Ecto.Changeset.put_change(:id, id)
    |> Repo.insert()
  end
end
